slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPGetConvergenceTest

Gets the method used to compute the error estimate used in the convergence test.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPGetConvergenceTest(PEP pep,PEPConv *conv)

Not Collective

### Input Parameters

| pep | - eigensolver context obtained from PEPCreate()

### Output Parameters

| conv | - the type of convergence test

### See Also

PEPSetConvergenceTest(), PEPConv

### Level

intermediate

### Location

src/pep/interface/pepopts.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages